@@ -27,15 +27,13 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a -O3 '
-           '-pipe -fstack-protector-strong -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection',
+           '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+           '-Wformat -Werror=format-security         -fstack-clash-protection '
+           '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -march=armv8-a -O3 -pipe -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -44,10 +42,9 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fstack-protector-strong '
-                     '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                     '-Wformat -Werror=format-security         '
-                     '-fstack-clash-protection',
+ 'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                     '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                     '-Werror=format-security         -fstack-clash-protection',
  'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
@@ -59,17 +56,17 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-dbmliborder=gdbm:ndbm' '--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv8-a "
-                '-O3 -pipe -fstack-protector-strong -fno-plt '
-                '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                '-O3 -pipe -fno-plt -fexceptions         '
+                '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                 "-Werror=format-security         -fstack-clash-protection' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.12.3/coverage.info',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.12.4/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.12.3/lcov-report',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.12.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -507,7 +504,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
- 'HAVE_STRLCPY': 0,
+ 'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRSIGNAL': 1,
  'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
@@ -641,15 +638,14 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a '
-                    '-O3 -pipe -fstack-protector-strong -fno-plt '
-                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-march=armv8-a -O3 -pipe -fstack-protector-strong '
-                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                    '-Wformat -Werror=format-security         '
-                    '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-                    '-fstack-protector-strong -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
                     '-std=c11 -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -658,14 +654,14 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a '
-                   '-O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
                    '-std=c11 -Werror=implicit-function-declaration '
                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -678,15 +674,14 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a '
-                    '-O3 -pipe -fstack-protector-strong -fno-plt '
-                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-march=armv8-a -O3 -pipe -fstack-protector-strong '
-                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                    '-Wformat -Werror=format-security         '
-                    '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-                    '-fstack-protector-strong -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
                     '-std=c11 -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -1054,44 +1049,42 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
-                             '-march=armv8-a -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-march=armv8-a -O3 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -march=armv8-a -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                             '-Wformat -Werror=format-security         '
+                             '-pipe -fno-plt -fexceptions         '
+                             '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                             '-Werror=format-security         '
                              '-fstack-clash-protection -march=armv8-a -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                             '-Wformat -Werror=format-security         '
+                             '-pipe -fno-plt -fexceptions         '
+                             '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                             '-Werror=format-security         '
                              '-fstack-clash-protection -std=c11 '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a -O3 '
-              '-pipe -fstack-protector-strong -fno-plt -fexceptions         '
-              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+              '-Wformat -Werror=format-security         '
+              '-fstack-clash-protection -march=armv8-a -O3 -pipe -fno-plt '
+              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
-              '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
-              '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
               '-Werror=format-security         -fstack-clash-protection',
  'PY_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a '
-                   '-O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
                    '-std=c11 -Werror=implicit-function-declaration '
                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -1111,17 +1104,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
-                        '-march=armv8-a -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-march=armv8-a -O3 -pipe -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                        '-Werror=format-security         '
+                        '-fstack-clash-protection -march=armv8-a -O3 -pipe '
+                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                         '-Wformat -Werror=format-security         '
                         '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                        '-Werror=format-security         '
-                        '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                        '-Werror=format-security         '
+                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                        '-Wformat -Werror=format-security         '
                         '-fstack-clash-protection -std=c11 '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
@@ -1137,7 +1128,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1263,9 +1254,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3 ./python -E '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4 ./python -E '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1282,7 +1273,7 @@ build_time_vars = {'ABIFLAGS': '',
  'WASM_ASSETS_DIR': './usr',
  'WASM_STDLIB': './usr/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '',
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -1295,8 +1286,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.12.3',
- 'abs_srcdir': '/build/python/src/Python-3.12.3',
+ 'abs_builddir': '/build/python/src/Python-3.12.4',
+ 'abs_srcdir': '/build/python/src/Python-3.12.4',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
